==> knights-trinity_3.5.13.2.orig.tar.xz: knights-trinity-3.5.13.2/knights/tabmanager.h <==
/***************************************************************************
                          tabmanager.h  -  description
                             -------------------
    begin                : Sat Sep 14 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABMANAGER_H
#define TABMANAGER_H

#include <tqobject.h>
#include <tqptrlist.h>
#include <kapp.h>
#include <kconfig.h>
#include "tabbox.h"

/**
  *@author Troy Corbin Jr.
  */

typedef TQPtrList<TabBox> TabBoxList;
class resource;

class TabManager : public TQObject
{
	Q_OBJECT
  TQ_OBJECT
	public:
								TabManager( resource *rsrc );
								~TabManager();
		void				addTab( TQWidget *child, const TQString &caption );
		void				childEvent( TQChildEvent *event );
		void				changeCaption( TQWidget *child, const TQString &caption );
		void				showTab( TQWidget *child );
		bool				isTab( TQWidget *child );

	public slots:
		void				removeTab( TQObject *child );

	protected slots:
		void				manageNewBox( TabBox *newBox );
		void				saveTabGeometry( const TQString&, const TQSize& );

	protected:
		TabBox*			getParentBox( TQWidget* );

	private:
		TabBoxList	myList;
		KConfig			*appConfig;
		resource		*myResource;
};

#endif

==> knights-trinity_14.1.0.orig.tar.xz: knights-trinity-14.1.0/knights/tabmanager.h <==
/***************************************************************************
                          tabmanager.h  -  description
                             -------------------
    begin                : Sat Sep 14 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABMANAGER_H
#define TABMANAGER_H

#include <tqobject.h>
#include <tqptrlist.h>
#include <kapp.h>
#include <tdeconfig.h>
#include "tabbox.h"

/**
  *@author Troy Corbin Jr.
  */

typedef TQPtrList<TabBox> TabBoxList;
class resource;

class TabManager : public TQObject
{
	Q_OBJECT
  
	public:
								TabManager( resource *rsrc );
								~TabManager();
		void				addTab( TQWidget *child, const TQString &caption );
		void				childEvent( TQChildEvent *event );
		void				changeCaption( TQWidget *child, const TQString &caption );
		void				showTab( TQWidget *child );
		bool				isTab( TQWidget *child );

	public slots:
		void				removeTab( TQObject *child );

	protected slots:
		void				manageNewBox( TabBox *newBox );
		void				saveTabGeometry( const TQString&, const TQSize& );

	protected:
		TabBox*			getParentBox( TQWidget* );

	private:
		TabBoxList	myList;
		TDEConfig			*appConfig;
		resource		*myResource;
};

#endif
